#!/bin/bash

# some distributions mount the root as read only until fsck has run,
# so we cannot edit xorg and create .activdevices.
# we need to wait until the root is writable, which happens 
# later.
# however, udev is synchronous, so we must relaunch ourselves async and exit.

if [ "$1" == "wait" ]; then
	while [ ! -w /tmp ]; do
		sleep 1
	done
	shift
else
	if [ ! -w /tmp ]; then
		$0 wait $1 &
		exit 0
	fi
fi

if [ "$1" == "add" ]; then

if [ "`id -u`" == "0" ]; then
	#make sure evdev is loaded first
	(/sbin/lsmod|grep -iq evdev) || modprobe evdev

	#add the promethean drivers if not there
	(/sbin/lsmod|grep -iq promethean) || modprobe promethean
fi

#reset the access rights for /dev/ACTIVBoard* (now done in udev)
# chmod 644 /dev/ACTIVBoard*

if [ ! -e "/etc/promethean/calibration" ]; then
	#create calibration directory with proper rights (user can write to it)
	mkdir -p /etc/promethean/calibration
	chmod -R 777 /etc/promethean/calibration
fi

# since HAL, udev seems to be called before ACTIVBoard<n> is available (sometimes)
[ "`ls /dev/ACTIVBoard* -1|wc -l`" == "0" ] && sleep 3

for f in /dev/ACTIVBoard* 
do
	if [ -e $f ]; then
		# beep the board
		echo -e ":BP\r\c" > $f
		#send the calibration to the device
		/usr/local/bin/activlc --load $f | logger
	fi
done

if [ -f /tmp/.activdevices ]; then
	rm /tmp/.activdevices
fi
echo add > /tmp/.activdevices
chmod 666 /tmp/.activdevices
logger "Promethean: device added"
elif [ "$1" == "remove" ]; then
	
	# remove but file not present, this can happen at startup if tmp was erased.
	# we need to create it first then delete so that gamin / fam picks it up.
	if [ ! -f /tmp/.activdevices ]; then
		echo add > /tmp/.activdevices
		chmod 666 /tmp/.activdevices
	fi
	rm /tmp/.activdevices
	rm /tmp/activboard*
	
	# if more devices, create the file again.
	# libactivboardex uses 1 of 3 mechanisms to detect changes:
	# FAM, Gamin and file polling.
	# FAM usually fails, something to do with the library.
	# Gamin checks for /tmp/.activdevices and is accurate
	# file polling checks for any file called /tmp/.activboard*
	for f in /dev/ACTIVBoard* 
	do
		if [ -e $f ]; then
			echo add > /tmp/.activdevices		
			chmod 666 /tmp/.activdevices	
			break
		fi
	done	

	logger "Promethean: device removed"
else
	logger "Promethean: invalid argument in promethean.sh "$1
fi

# create the activboard[n] for file polling method
for f in /dev/ACTIVBoard* 
do
	if [ -e $f ]; then
		BFILE="/tmp/`basename $f|tr [:upper:] [:lower:]`"
		echo add > $BFILE
		chmod 666 $BFILE
	fi
done

